@@ -2,7 +2,7 @@
 /*
  * redcloth_attributes.c.rl
  *
- * Copyright (C) 2008 Jason Garber
+ * Copyright (C) 2009 Jason Garber
  */
 #include <ruby.h>
 #include "redcloth.h"
@@ -32,17 +32,17 @@ static const char _redcloth_attributes_actions[] = {
 static const short _redcloth_attributes_key_offsets[] = {
 	0, 0, 6, 11, 13, 14, 15, 23, 
 	29, 34, 38, 46, 53, 60, 66, 72, 
-	73, 80, 86, 87, 94, 100, 108, 115, 
-	122, 128, 134, 139, 145, 153, 160, 167, 
-	173, 179, 186, 192, 199, 205, 212, 218, 
-	225, 231, 233, 235, 236, 237, 244, 250, 
-	255, 263, 270, 277, 283, 284, 291, 297, 
-	298, 305, 311, 312, 313, 320, 326, 334, 
-	342, 348, 356, 364, 371, 378, 388, 395, 
-	402, 409, 416, 423, 430, 437, 447, 453, 
-	461, 469, 476, 483, 493, 500, 507, 514, 
-	521, 528, 535, 542, 549, 556, 559, 565, 
-	573, 581, 588, 595, 604, 611, 618, 625
+	74, 82, 89, 90, 97, 103, 111, 118, 
+	125, 131, 137, 142, 148, 156, 163, 170, 
+	176, 182, 190, 197, 204, 210, 218, 225, 
+	232, 238, 240, 242, 243, 244, 251, 257, 
+	262, 270, 277, 284, 290, 292, 300, 307, 
+	308, 315, 321, 323, 324, 331, 337, 345, 
+	353, 359, 367, 375, 382, 389, 399, 406, 
+	414, 422, 429, 436, 443, 450, 460, 466, 
+	474, 482, 489, 496, 506, 513, 521, 529, 
+	536, 543, 551, 559, 566, 573, 576, 582, 
+	590, 598, 605, 612, 621, 629, 637, 644
 };
 
 static const char _redcloth_attributes_trans_keys[] = {
@@ -55,93 +55,95 @@ static const char _redcloth_attributes_trans_keys[] = {
 	32, 35, 41, 10, 13, 0, 9, 10, 
 	32, 41, 11, 13, 0, 9, 32, 41, 
 	10, 13, 0, 9, 10, 32, 11, 13, 
-	93, 0, 9, 10, 32, 93, 11, 13, 
-	0, 9, 32, 93, 10, 13, 125, 0, 
-	9, 10, 32, 125, 11, 13, 0, 9, 
-	32, 125, 10, 13, 0, 9, 10, 32, 
+	91, 93, 0, 9, 10, 32, 91, 93, 
+	11, 13, 0, 9, 32, 91, 93, 10, 
+	13, 125, 0, 9, 10, 32, 125, 11, 
+	13, 0, 9, 32, 125, 10, 13, 0, 
+	9, 10, 32, 35, 41, 11, 13, 0, 
+	9, 32, 35, 41, 10, 13, 0, 9, 
+	10, 32, 41, 11, 13, 0, 9, 32, 
+	41, 10, 13, 0, 9, 10, 32, 11, 
+	13, 0, 9, 32, 10, 13, 0, 9, 
+	10, 32, 11, 13, 0, 9, 10, 32, 
 	35, 41, 11, 13, 0, 9, 32, 35, 
 	41, 10, 13, 0, 9, 10, 32, 41, 
 	11, 13, 0, 9, 32, 41, 10, 13, 
 	0, 9, 10, 32, 11, 13, 0, 9, 
-	32, 10, 13, 0, 9, 10, 32, 11, 
-	13, 0, 9, 10, 32, 35, 41, 11, 
-	13, 0, 9, 32, 35, 41, 10, 13, 
-	0, 9, 10, 32, 41, 11, 13, 0, 
-	9, 32, 41, 10, 13, 0, 9, 10, 
-	32, 11, 13, 0, 9, 10, 32, 93, 
-	11, 13, 0, 9, 32, 93, 10, 13, 
-	0, 9, 10, 32, 125, 11, 13, 0, 
-	9, 32, 125, 10, 13, 0, 9, 10, 
-	32, 93, 11, 13, 0, 9, 32, 93, 
-	10, 13, 0, 9, 10, 32, 125, 11, 
-	13, 0, 9, 32, 125, 10, 13, 35, 
-	41, 35, 41, 41, 41, 0, 32, 40, 
-	91, 123, 9, 13, 0, 9, 10, 32, 
-	11, 13, 0, 9, 32, 10, 13, 0, 
-	9, 10, 32, 35, 41, 11, 13, 0, 
-	9, 32, 35, 41, 10, 13, 0, 9, 
-	10, 32, 41, 11, 13, 0, 9, 32, 
-	41, 10, 13, 93, 0, 9, 10, 32, 
-	93, 11, 13, 0, 9, 32, 93, 10, 
-	13, 125, 0, 9, 10, 32, 125, 11, 
-	13, 0, 9, 32, 125, 10, 13, 93, 
-	125, 0, 32, 40, 91, 123, 9, 13, 
-	0, 9, 10, 32, 11, 13, 0, 9, 
-	10, 32, 35, 41, 11, 13, 0, 9, 
-	10, 32, 35, 41, 11, 13, 0, 9, 
-	10, 32, 11, 13, 0, 9, 10, 32, 
-	35, 41, 11, 13, 0, 9, 10, 32, 
-	35, 41, 11, 13, 0, 9, 10, 32, 
-	41, 11, 13, 0, 9, 10, 32, 41, 
-	11, 13, 0, 9, 10, 32, 40, 46, 
-	91, 123, 11, 13, 0, 9, 10, 32, 
-	46, 11, 13, 0, 9, 10, 32, 93, 
-	11, 13, 0, 9, 10, 32, 93, 11, 
+	10, 32, 91, 93, 11, 13, 0, 9, 
+	32, 91, 93, 10, 13, 0, 9, 10, 
+	32, 125, 11, 13, 0, 9, 32, 125, 
+	10, 13, 0, 9, 10, 32, 91, 93, 
+	11, 13, 0, 9, 32, 91, 93, 10, 
 	13, 0, 9, 10, 32, 125, 11, 13, 
-	0, 9, 10, 32, 125, 11, 13, 0, 
+	0, 9, 32, 125, 10, 13, 35, 41, 
+	35, 41, 41, 41, 0, 32, 40, 91, 
+	123, 9, 13, 0, 9, 10, 32, 11, 
+	13, 0, 9, 32, 10, 13, 0, 9, 
+	10, 32, 35, 41, 11, 13, 0, 9, 
+	32, 35, 41, 10, 13, 0, 9, 10, 
+	32, 41, 11, 13, 0, 9, 32, 41, 
+	10, 13, 91, 93, 0, 9, 10, 32, 
+	91, 93, 11, 13, 0, 9, 32, 91, 
+	93, 10, 13, 125, 0, 9, 10, 32, 
+	125, 11, 13, 0, 9, 32, 125, 10, 
+	13, 91, 93, 125, 0, 32, 40, 91, 
+	123, 9, 13, 0, 9, 10, 32, 11, 
+	13, 0, 9, 10, 32, 35, 41, 11, 
+	13, 0, 9, 10, 32, 35, 41, 11, 
+	13, 0, 9, 10, 32, 11, 13, 0, 
+	9, 10, 32, 35, 41, 11, 13, 0, 
+	9, 10, 32, 35, 41, 11, 13, 0, 
 	9, 10, 32, 41, 11, 13, 0, 9, 
 	10, 32, 41, 11, 13, 0, 9, 10, 
 	32, 40, 46, 91, 123, 11, 13, 0, 
-	9, 10, 32, 11, 13, 0, 9, 10, 
-	32, 35, 41, 11, 13, 0, 9, 10, 
-	32, 35, 41, 11, 13, 0, 9, 10, 
-	32, 41, 11, 13, 0, 9, 10, 32, 
-	41, 11, 13, 0, 9, 10, 32, 40, 
-	46, 91, 123, 11, 13, 0, 9, 10, 
-	32, 46, 11, 13, 0, 9, 10, 32, 
-	93, 11, 13, 0, 9, 10, 32, 93, 
-	11, 13, 0, 9, 10, 32, 125, 11, 
-	13, 0, 9, 10, 32, 125, 11, 13, 
-	0, 9, 10, 32, 93, 11, 13, 0, 
-	9, 10, 32, 93, 11, 13, 0, 9, 
+	9, 10, 32, 46, 11, 13, 0, 9, 
+	10, 32, 91, 93, 11, 13, 0, 9, 
+	10, 32, 91, 93, 11, 13, 0, 9, 
 	10, 32, 125, 11, 13, 0, 9, 10, 
-	32, 125, 11, 13, 40, 91, 123, 0, 
-	9, 10, 32, 11, 13, 0, 9, 10, 
-	32, 35, 41, 11, 13, 0, 9, 10, 
-	32, 35, 41, 11, 13, 0, 9, 10, 
-	32, 41, 11, 13, 0, 9, 10, 32, 
-	41, 11, 13, 0, 9, 10, 32, 40, 
+	32, 125, 11, 13, 0, 9, 10, 32, 
+	41, 11, 13, 0, 9, 10, 32, 41, 
+	11, 13, 0, 9, 10, 32, 40, 46, 
 	91, 123, 11, 13, 0, 9, 10, 32, 
-	93, 11, 13, 0, 9, 10, 32, 93, 
-	11, 13, 0, 9, 10, 32, 125, 11, 
+	11, 13, 0, 9, 10, 32, 35, 41, 
+	11, 13, 0, 9, 10, 32, 35, 41, 
+	11, 13, 0, 9, 10, 32, 41, 11, 
+	13, 0, 9, 10, 32, 41, 11, 13, 
+	0, 9, 10, 32, 40, 46, 91, 123, 
+	11, 13, 0, 9, 10, 32, 46, 11, 
+	13, 0, 9, 10, 32, 91, 93, 11, 
+	13, 0, 9, 10, 32, 91, 93, 11, 
 	13, 0, 9, 10, 32, 125, 11, 13, 
-	0
+	0, 9, 10, 32, 125, 11, 13, 0, 
+	9, 10, 32, 91, 93, 11, 13, 0, 
+	9, 10, 32, 91, 93, 11, 13, 0, 
+	9, 10, 32, 125, 11, 13, 0, 9, 
+	10, 32, 125, 11, 13, 40, 91, 123, 
+	0, 9, 10, 32, 11, 13, 0, 9, 
+	10, 32, 35, 41, 11, 13, 0, 9, 
+	10, 32, 35, 41, 11, 13, 0, 9, 
+	10, 32, 41, 11, 13, 0, 9, 10, 
+	32, 41, 11, 13, 0, 9, 10, 32, 
+	40, 91, 123, 11, 13, 0, 9, 10, 
+	32, 91, 93, 11, 13, 0, 9, 10, 
+	32, 91, 93, 11, 13, 0, 9, 10, 
+	32, 125, 11, 13, 0, 9, 10, 32, 
+	125, 11, 13, 0
 };
 
 static const char _redcloth_attributes_single_lengths[] = {
 	0, 4, 3, 2, 1, 1, 6, 4, 
-	3, 2, 6, 5, 5, 4, 4, 1, 
-	5, 4, 1, 5, 4, 6, 5, 5, 
+	3, 2, 6, 5, 5, 4, 4, 2, 
+	6, 5, 1, 5, 4, 6, 5, 5, 
 	4, 4, 3, 4, 6, 5, 5, 4, 
-	4, 5, 4, 5, 4, 5, 4, 5, 
+	4, 6, 5, 5, 4, 6, 5, 5, 
 	4, 2, 2, 1, 1, 5, 4, 3, 
-	6, 5, 5, 4, 1, 5, 4, 1, 
-	5, 4, 1, 1, 5, 4, 6, 6, 
-	4, 6, 6, 5, 5, 8, 5, 5, 
-	5, 5, 5, 5, 5, 8, 4, 6, 
-	6, 5, 5, 8, 5, 5, 5, 5, 
-	5, 5, 5, 5, 5, 3, 4, 6, 
-	6, 5, 5, 7, 5, 5, 5, 5
+	6, 5, 5, 4, 2, 6, 5, 1, 
+	5, 4, 2, 1, 5, 4, 6, 6, 
+	4, 6, 6, 5, 5, 8, 5, 6, 
+	6, 5, 5, 5, 5, 8, 4, 6, 
+	6, 5, 5, 8, 5, 6, 6, 5, 
+	5, 6, 6, 5, 5, 3, 4, 6, 
+	6, 5, 5, 7, 6, 6, 5, 5
 };
 
 static const char _redcloth_attributes_range_lengths[] = {
@@ -163,17 +165,17 @@ static const char _redcloth_attributes_range_lengths[] = {
 static const short _redcloth_attributes_index_offsets[] = {
 	0, 0, 6, 11, 14, 16, 18, 26, 
 	32, 37, 41, 49, 56, 63, 69, 75, 
-	77, 84, 90, 92, 99, 105, 113, 120, 
-	127, 133, 139, 144, 150, 158, 165, 172, 
-	178, 184, 191, 197, 204, 210, 217, 223, 
-	230, 236, 239, 242, 244, 246, 253, 259, 
-	264, 272, 279, 286, 292, 294, 301, 307, 
-	309, 316, 322, 324, 326, 333, 339, 347, 
-	355, 361, 369, 377, 384, 391, 401, 408, 
-	415, 422, 429, 436, 443, 450, 460, 466, 
-	474, 482, 489, 496, 506, 513, 520, 527, 
-	534, 541, 548, 555, 562, 569, 573, 579, 
-	587, 595, 602, 609, 618, 625, 632, 639
+	78, 86, 93, 95, 102, 108, 116, 123, 
+	130, 136, 142, 147, 153, 161, 168, 175, 
+	181, 187, 195, 202, 209, 215, 223, 230, 
+	237, 243, 246, 249, 251, 253, 260, 266, 
+	271, 279, 286, 293, 299, 302, 310, 317, 
+	319, 326, 332, 335, 337, 344, 350, 358, 
+	366, 372, 380, 388, 395, 402, 412, 419, 
+	427, 435, 442, 449, 456, 463, 473, 479, 
+	487, 495, 502, 509, 519, 526, 534, 542, 
+	549, 556, 564, 572, 579, 586, 590, 596, 
+	604, 612, 619, 626, 635, 643, 651, 658
 };
 
 static const unsigned char _redcloth_attributes_indicies[] = {
@@ -186,78 +188,81 @@ static const unsigned char _redcloth_attributes_indicies[] = {
 	21, 5, 22, 22, 24, 25, 5, 21, 
 	9, 27, 28, 27, 29, 9, 26, 9, 
 	27, 27, 29, 9, 26, 17, 19, 20, 
-	30, 17, 11, 32, 31, 31, 34, 35, 
-	34, 36, 31, 33, 31, 34, 34, 36, 
-	31, 33, 38, 37, 37, 40, 41, 40, 
-	42, 37, 39, 37, 40, 40, 42, 37, 
-	39, 5, 44, 45, 44, 46, 47, 5, 
-	43, 5, 44, 44, 46, 47, 5, 43, 
-	9, 49, 50, 49, 51, 9, 48, 9, 
-	49, 49, 51, 9, 48, 17, 53, 54, 
-	53, 17, 52, 17, 53, 53, 17, 52, 
-	0, 2, 3, 56, 0, 55, 5, 58, 
-	59, 58, 60, 61, 5, 57, 5, 58, 
-	58, 60, 61, 5, 57, 9, 63, 64, 
-	63, 65, 9, 62, 9, 63, 63, 65, 
-	9, 62, 17, 53, 54, 66, 17, 55, 
-	31, 68, 69, 68, 70, 31, 67, 31, 
-	68, 68, 70, 31, 67, 37, 72, 73, 
-	72, 74, 37, 71, 37, 72, 72, 74, 
-	37, 71, 31, 76, 77, 76, 78, 31, 
-	75, 31, 76, 76, 78, 31, 75, 37, 
-	80, 81, 80, 82, 37, 79, 37, 80, 
-	80, 82, 37, 79, 84, 85, 83, 88, 
-	89, 87, 86, 90, 92, 91, 86, 86, 
-	94, 95, 96, 86, 93, 97, 99, 100, 
-	99, 97, 98, 97, 99, 99, 97, 98, 
-	87, 102, 103, 102, 104, 105, 87, 101, 
-	87, 102, 102, 104, 105, 87, 101, 91, 
-	107, 108, 107, 109, 91, 106, 91, 107, 
-	107, 109, 91, 106, 111, 110, 110, 113, 
-	114, 113, 115, 110, 112, 110, 113, 113, 
-	115, 110, 112, 117, 116, 116, 119, 120, 
-	119, 121, 116, 118, 116, 119, 119, 121, 
-	116, 118, 123, 122, 123, 124, 123, 123, 
-	126, 127, 128, 123, 125, 129, 2, 3, 
-	2, 129, 1, 131, 132, 133, 132, 134, 
-	135, 131, 130, 136, 44, 45, 44, 46, 
-	47, 136, 43, 137, 19, 20, 19, 137, 
-	18, 139, 140, 141, 140, 142, 143, 139, 
-	138, 5, 22, 23, 22, 24, 25, 5, 
-	21, 8, 145, 146, 145, 18, 8, 144, 
-	9, 27, 28, 27, 29, 9, 26, 137, 
-	19, 20, 30, 13, 14, 15, 16, 137, 
-	11, 137, 19, 20, 30, 14, 137, 11, 
-	148, 149, 150, 149, 18, 148, 147, 31, 
-	34, 35, 34, 36, 31, 33, 152, 153, 
-	154, 153, 18, 152, 151, 37, 40, 41, 
-	40, 42, 37, 39, 156, 157, 158, 157, 
-	1, 156, 155, 159, 49, 50, 49, 51, 
-	159, 48, 129, 2, 3, 56, 160, 161, 
-	162, 163, 129, 55, 164, 53, 54, 53, 
-	164, 52, 131, 166, 167, 166, 168, 169, 
-	131, 165, 136, 58, 59, 58, 60, 61, 
-	136, 57, 156, 171, 172, 171, 52, 156, 
-	170, 159, 63, 64, 63, 65, 159, 62, 
-	164, 53, 54, 66, 160, 161, 162, 163, 
-	164, 55, 164, 53, 54, 66, 161, 164, 
-	55, 174, 175, 176, 175, 52, 174, 173, 
-	177, 68, 69, 68, 70, 177, 67, 179, 
-	180, 181, 180, 52, 179, 178, 182, 72, 
-	73, 72, 74, 182, 71, 174, 184, 185, 
-	184, 1, 174, 183, 177, 76, 77, 76, 
-	78, 177, 75, 179, 187, 188, 187, 1, 
-	179, 186, 182, 80, 81, 80, 82, 182, 
-	79, 189, 190, 191, 123, 192, 99, 100, 
-	99, 192, 98, 83, 194, 195, 194, 196, 
-	197, 83, 193, 87, 102, 103, 102, 104, 
-	105, 87, 101, 90, 199, 200, 199, 98, 
-	90, 198, 91, 107, 108, 107, 109, 91, 
-	106, 192, 99, 100, 99, 94, 95, 96, 
-	192, 93, 122, 202, 203, 202, 98, 122, 
-	201, 110, 113, 114, 113, 115, 110, 112, 
-	124, 205, 206, 205, 98, 124, 204, 116, 
-	119, 120, 119, 121, 116, 118, 0
+	30, 17, 11, 4, 32, 31, 31, 34, 
+	35, 34, 18, 36, 31, 33, 31, 34, 
+	34, 18, 36, 31, 33, 38, 37, 37, 
+	40, 41, 40, 42, 37, 39, 37, 40, 
+	40, 42, 37, 39, 5, 44, 45, 44, 
+	46, 47, 5, 43, 5, 44, 44, 46, 
+	47, 5, 43, 9, 49, 50, 49, 51, 
+	9, 48, 9, 49, 49, 51, 9, 48, 
+	17, 53, 54, 53, 17, 52, 17, 53, 
+	53, 17, 52, 0, 2, 3, 56, 0, 
+	55, 5, 58, 59, 58, 60, 61, 5, 
+	57, 5, 58, 58, 60, 61, 5, 57, 
+	9, 63, 64, 63, 65, 9, 62, 9, 
+	63, 63, 65, 9, 62, 17, 53, 54, 
+	66, 17, 55, 31, 68, 69, 68, 52, 
+	70, 31, 67, 31, 68, 68, 52, 70, 
+	31, 67, 37, 72, 73, 72, 74, 37, 
+	71, 37, 72, 72, 74, 37, 71, 31, 
+	76, 77, 76, 1, 78, 31, 75, 31, 
+	76, 76, 1, 78, 31, 75, 37, 80, 
+	81, 80, 82, 37, 79, 37, 80, 80, 
+	82, 37, 79, 84, 85, 83, 88, 89, 
+	87, 86, 90, 92, 91, 86, 86, 94, 
+	95, 96, 86, 93, 97, 99, 100, 99, 
+	97, 98, 97, 99, 99, 97, 98, 87, 
+	102, 103, 102, 104, 105, 87, 101, 87, 
+	102, 102, 104, 105, 87, 101, 91, 107, 
+	108, 107, 109, 91, 106, 91, 107, 107, 
+	109, 91, 106, 86, 111, 110, 110, 113, 
+	114, 113, 98, 115, 110, 112, 110, 113, 
+	113, 98, 115, 110, 112, 117, 116, 116, 
+	119, 120, 119, 121, 116, 118, 116, 119, 
+	119, 121, 116, 118, 123, 123, 122, 123, 
+	124, 123, 123, 126, 127, 128, 123, 125, 
+	129, 2, 3, 2, 129, 1, 131, 132, 
+	133, 132, 134, 135, 131, 130, 136, 44, 
+	45, 44, 46, 47, 136, 43, 137, 19, 
+	20, 19, 137, 18, 139, 140, 141, 140, 
+	142, 143, 139, 138, 5, 22, 23, 22, 
+	24, 25, 5, 21, 8, 145, 146, 145, 
+	18, 8, 144, 9, 27, 28, 27, 29, 
+	9, 26, 137, 19, 20, 30, 13, 14, 
+	15, 16, 137, 11, 137, 19, 20, 30, 
+	14, 137, 11, 148, 149, 150, 149, 18, 
+	18, 148, 147, 31, 34, 35, 34, 18, 
+	36, 31, 33, 152, 153, 154, 153, 18, 
+	152, 151, 37, 40, 41, 40, 42, 37, 
+	39, 156, 157, 158, 157, 1, 156, 155, 
+	159, 49, 50, 49, 51, 159, 48, 129, 
+	2, 3, 56, 160, 161, 162, 163, 129, 
+	55, 164, 53, 54, 53, 164, 52, 131, 
+	166, 167, 166, 168, 169, 131, 165, 136, 
+	58, 59, 58, 60, 61, 136, 57, 156, 
+	171, 172, 171, 52, 156, 170, 159, 63, 
+	64, 63, 65, 159, 62, 164, 53, 54, 
+	66, 160, 161, 162, 163, 164, 55, 164, 
+	53, 54, 66, 161, 164, 55, 174, 175, 
+	176, 175, 52, 52, 174, 173, 177, 68, 
+	69, 68, 52, 70, 177, 67, 179, 180, 
+	181, 180, 52, 179, 178, 182, 72, 73, 
+	72, 74, 182, 71, 174, 184, 185, 184, 
+	1, 1, 174, 183, 177, 76, 77, 76, 
+	1, 78, 177, 75, 179, 187, 188, 187, 
+	1, 179, 186, 182, 80, 81, 80, 82, 
+	182, 79, 189, 190, 191, 123, 192, 99, 
+	100, 99, 192, 98, 83, 194, 195, 194, 
+	196, 197, 83, 193, 87, 102, 103, 102, 
+	104, 105, 87, 101, 90, 199, 200, 199, 
+	98, 90, 198, 91, 107, 108, 107, 109, 
+	91, 106, 192, 99, 100, 99, 94, 95, 
+	96, 192, 93, 122, 202, 203, 202, 98, 
+	98, 122, 201, 110, 113, 114, 113, 98, 
+	115, 110, 112, 124, 205, 206, 205, 98, 
+	124, 204, 116, 119, 120, 119, 121, 116, 
+	118, 0
 };
 
 static const char _redcloth_attributes_trans_targs[] = {
@@ -382,24 +387,23 @@ redcloth_attribute_parser(machine, self, p, pe)
   char *p, *pe;
 {
   int cs, act;
-  char *ts, *te, *reg, *bck, *eof;
+  char *ts = 0, *te = 0, *reg = 0, *bck = NULL, *eof = NULL;
   VALUE regs = rb_hash_new();
-  VALUE buf = Qnil;
 
   
-#line 391 "ext/redcloth_scan/redcloth_attributes.c"
+#line 395 "ext/redcloth_scan/redcloth_attributes.c"
 	{
 	cs = redcloth_attributes_start;
 	ts = 0;
 	te = 0;
 	act = 0;
 	}
-#line 32 "ext/redcloth_scan/redcloth_attributes.c.rl"
+#line 31 "ext/redcloth_scan/redcloth_attributes.c.rl"
 
   cs = machine;
 
   
-#line 403 "ext/redcloth_scan/redcloth_attributes.c"
+#line 407 "ext/redcloth_scan/redcloth_attributes.c"
 	{
 	int _klen;
 	unsigned int _trans;
@@ -420,7 +424,7 @@ _resume:
 #line 1 "ext/redcloth_scan/redcloth_attributes.c.rl"
 	{ts = p;}
 	break;
-#line 424 "ext/redcloth_scan/redcloth_attributes.c"
+#line 428 "ext/redcloth_scan/redcloth_attributes.c"
 		}
 	}
 
@@ -590,7 +594,7 @@ _eof_trans:
 	}
 	}
 	break;
-#line 594 "ext/redcloth_scan/redcloth_attributes.c"
+#line 598 "ext/redcloth_scan/redcloth_attributes.c"
 		}
 	}
 
@@ -607,7 +611,7 @@ _again:
 #line 1 "ext/redcloth_scan/redcloth_attributes.c.rl"
 	{act = 0;}
 	break;
-#line 611 "ext/redcloth_scan/redcloth_attributes.c"
+#line 615 "ext/redcloth_scan/redcloth_attributes.c"
 		}
 	}
 
@@ -626,7 +630,7 @@ _again:
 
 	_out: {}
 	}
-#line 36 "ext/redcloth_scan/redcloth_attributes.c.rl"
+#line 35 "ext/redcloth_scan/redcloth_attributes.c.rl"
 
   return regs;
 }
